Test coverage report: user_media.processors

# user_media.processors: 4 total statements, 100.0% covered

Generated: Mon 2014-08-04 18:55 CEST

Source file: /home/tobi/Projects/django-user-media/src/user_media/processors.py

Stats: 4 executed, 0 missed, 0 excluded, 4 ignored

1. `"""Image processors for easy_thumbnails."""`
2. ``
3. ``
4. `def crop_box(im, box=False, **kwargs):`
5. `"""Uses box coordinates to crop an image without resizing it first."""`
6. `if box:`
7. `im = im.crop(box)`
8. `return im`